from __future__ import unicode_literals
import re
import importlib
from decimal import Decimal


unit_conversion_re = re.compile(r'''
    ^
    (?P<num>\d+[.\d*]?)
    [\t ]+
    (?P<unit_from>[A-Za-z]+)
    [\t ]+
    (?:to|in)
    [\t ]+
    (?P<unit_to>[A-Z-a-z]+)
    $
    ''', 
    re.VERBOSE
)


units = (
    'digital',
    'length',
    'temperature',
    'time',
    'weight',
)


def convert(num, unit_from, unit_to):
    for unit in units:
        package = importlib.import_module('plz.units.' + unit)
        actual_unit_from, actual_unit_to = None, None
        for unit_list in package.UNITS:
            if unit_from in unit_list:
                actual_unit_from = unit_list[0]
            if unit_to in unit_list:
                actual_unit_to = unit_list[0]

        if actual_unit_from and actual_unit_to:
            func = package.CONV[actual_unit_from][actual_unit_to]
            return func(Decimal(num))

