from plz.functional import _


UNITS = [
    ('b', 'byte', 'bytes'),
    ('kb', 'kilobyte', 'kilobytes'),
    ('mb', 'megabyte', 'megabytes'),
    ('gb', 'gigabyte', 'gigabytes'),
    ('tb', 'terabyte', 'terabytes'),

    ('bit', 'bits'),
    ('kbit', 'kilobit', 'kylobits',),
    ('mbit', 'megabit', 'megabits',),
    ('gbit', 'gigabit', 'gagabits',),
    ('tbit', 'terabit', 'terabits',),

    ('kib', 'kibibyte', 'kibibytes',),
    ('mib', 'mebibyte', 'mebibytes',),
    ('gib', 'gibibyte', 'gibibytes',),
    ('tib', 'tebibyte', 'tebibytes',),
]


CONV = {
    'b': {
        'b':  _,
        'kb': _ / 1000,
        'mb': _ / 1000000,
        'gb': _ / 1000000000,
        'tb': _ / 1000000000000,

        'bit':  _ * 8,
        'kbit': _ * 8 / 1000,
        'mbit': _ * 8 / 1000000,
        'gbit': _ * 8 / 1000000000,
        'tbit': _ * 8 / 1000000000000,

        'kib': _ / (2 ** 10),
        'mib': _ / (2 ** 20),
        'gib': _ / (2 ** 30),
        'tib': _ / (2 ** 40),
    },
    'kb': {
        'b':  _ * 1000,
        'kb': _,
        'mb': _ / 1000,
        'gb': _ / 1000000,
        'tb': _ / 1000000000,

        'bit':  _ * 8 * 1000,
        'kbit': _ * 8,
        'mbit': _ * 8 / 1000,
        'gbit': _ * 8 / 1000000,
        'tbit': _ * 8 / 1000000000,

        'kib': _ / (2 ** 10) * 1000,
        'mib': _ / (2 ** 20) * 1000,
        'gib': _ / (2 ** 30) * 1000,
        'tib': _ / (2 ** 40) * 1000,
    },
    'mb': {
        'b':  _ * 1000000,
        'kb': _ * 1000,
        'mb': _,
        'gb': _ / 1000,
        'tb': _ / 1000000,

        'bit':  _ * 8 * 1000000,
        'kbit': _ * 8 * 1000,
        'mbit': _ * 8,
        'gbit': _ * 8 / 1000,
        'tbit': _ * 8 / 1000000,

        'kib': _ / (2 ** 10) * 1000000,
        'mib': _ / (2 ** 20) * 1000000,
        'gib': _ / (2 ** 30) * 1000000,
        'tib': _ / (2 ** 40) * 1000000,
    },
    'gb': {
        'b':  _ * 1000000000,
        'kb': _ * 1000000,
        'mb': _ * 1000,
        'gb': _,
        'tb': _ / 1000,

        'bit':  _ * 8 * 1000000000,
        'kbit': _ * 8 * 1000000,
        'mbit': _ * 8 * 1000,
        'gbit': _ * 8,
        'tbit': _ * 8 / 1000,

        'kib': _ / (2 ** 10) * 1000000000,
        'mib': _ / (2 ** 20) * 1000000000,
        'gib': _ / (2 ** 30) * 1000000000,
        'tib': _ / (2 ** 40) * 1000000000,
    },
    'tb': {
        'b':  _ * 1000000000000,
        'kb': _ * 1000000000,
        'mb': _ * 1000000,
        'gb': _ * 1000,
        'tb': _,

        'bit':  _ * 8 * 1000000000000,
        'kbit': _ * 8 * 1000000000,
        'mbit': _ * 8 * 1000000,
        'gbit': _ * 8 * 1000,
        'tbit': _ * 8,

        'kib': _ / (2 ** 10) * 1000000000000,
        'mib': _ / (2 ** 20) * 1000000000000,
        'gib': _ / (2 ** 30) * 1000000000000,
        'tib': _ / (2 ** 40) * 1000000000000,
    },

    'bit': {
        'b':  _ / 8,
        'kb': _ / 8 / 1000,
        'mb': _ / 8 / 1000000,
        'gb': _ / 8 / 1000000000,
        'tb': _ / 8 / 1000000000000,

        'bit':  _,
        'kbit': _ / 1000,
        'mbit': _ / 1000000,
        'gbit': _ / 1000000000,
        'tbit': _ / 1000000000000,

        'kib': _ / (2 ** 10) / 8,
        'mib': _ / (2 ** 20) / 8,
        'gib': _ / (2 ** 30) / 8,
        'tib': _ / (2 ** 40) / 8,
    },
    'kbit': {
        'b':  _ / 8 * 1000,
        'kb': _ / 8,
        'mb': _ / 8 / 1000,
        'gb': _ / 8 / 1000000,
        'tb': _ / 8 / 1000000000,

        'bit':  _ * 1000,
        'kbit': _,
        'mbit': _ / 1000,
        'gbit': _ / 1000000,
        'tbit': _ / 1000000000,

        'kib': _ / (2 ** 10) / 8 * 1000,
        'mib': _ / (2 ** 20) / 8 * 1000,
        'gib': _ / (2 ** 30) / 8 * 1000,
        'tib': _ / (2 ** 40) / 8 * 1000,
    },
    'mbit': {
        'b':  _ / 8 * 1000000,
        'kb': _ / 8 * 1000,
        'mb': _ / 8,
        'gb': _ / 8 / 1000,
        'tb': _ / 8 / 1000000,

        'bit':  _ * 1000000,
        'kbit': _ * 1000,
        'mbit': _,
        'gbit': _ / 1000,
        'tbit': _ / 1000000,

        'kib': _ / (2 ** 10) / 8 * 1000000,
        'mib': _ / (2 ** 20) / 8 * 1000000,
        'gib': _ / (2 ** 30) / 8 * 1000000,
        'tib': _ / (2 ** 40) / 8 * 1000000,
    },
    'gbit': {
        'b':  _ / 8 * 1000000000,
        'kb': _ / 8 * 1000000,
        'mb': _ / 8 * 1000,
        'gb': _ / 8,
        'tb': _ / 8 / 1000,

        'bit':  _ * 1000000000,
        'kbit': _ * 1000000,
        'mbit': _ * 1000,
        'gbit': _,
        'tbit': _ / 1000,

        'kib': _ / (2 ** 10) / 8 * 1000000000,
        'mib': _ / (2 ** 20) / 8 * 1000000000,
        'gib': _ / (2 ** 30) / 8 * 1000000000,
        'tib': _ / (2 ** 40) / 8 * 1000000000,
    },
    'tbit': {
        'b':  _ / 8 * 1000000000000,
        'kb': _ / 8 * 1000000000,
        'mb': _ / 8 * 1000000,
        'gb': _ / 8 * 1000,
        'tb': _ / 8,

        'bit':  _ * 1000000000000,
        'kbit': _ * 1000000000,
        'mbit': _ * 1000000,
        'gbit': _ * 1000,
        'tbit': _,

        'kib': _ / (2 ** 10) / 8 * 1000000000000,
        'mib': _ / (2 ** 20) / 8 * 1000000000000,
        'gib': _ / (2 ** 30) / 8 * 1000000000000,
        'tib': _ / (2 ** 40) / 8 * 1000000000000,
    },
    'kib': {
        'b':  _ * (2 ** 10),
        'kb': _ * (2 ** 10) / 1000,
        'mb': _ * (2 ** 10) / 1000000,
        'gb': _ * (2 ** 10) / 1000000000,
        'tb': _ * (2 ** 10) / 1000000000000,

        'bit':  _ * (2 ** 10) * 8,
        'kbit': _ * (2 ** 10) * 8 / 1000,
        'mbit': _ * (2 ** 10) * 8 / 1000000,
        'gbit': _ * (2 ** 10) * 8 / 1000000000,
        'tbit': _ * (2 ** 10) * 8 / 1000000000000,

        'kib': _,
        'mib': _ / (2 ** 10),
        'gib': _ / (2 ** 20),
        'tib': _ / (2 ** 30),
    },
    'mib': {
        'b':  _ * (2 ** 20),
        'kb': _ * (2 ** 20) / 1000,
        'mb': _ * (2 ** 20) / 1000000,
        'gb': _ * (2 ** 20) / 1000000000,
        'tb': _ * (2 ** 20) / 1000000000000,

        'bit':  _ * (2 ** 20) * 8,
        'kbit': _ * (2 ** 20) * 8 / 1000,
        'mbit': _ * (2 ** 20) * 8 / 1000000,
        'gbit': _ * (2 ** 20) * 8 / 1000000000,
        'tbit': _ * (2 ** 20) * 8 / 1000000000000,

        'kib': _ * (2 ** 10),
        'mib': _,
        'gib': _ / (2 ** 10),
        'tib': _ / (2 ** 20),
    },
    'gib': {
         'b': _ * (2 ** 30),
        'kb': _ * (2 ** 30) / 1000,
        'mb': _ * (2 ** 30) / 1000000,
        'gb': _ * (2 ** 30) / 1000000000,
        'tb': _ * (2 ** 30) / 1000000000000,

        'bit':  _ * (2 ** 30) * 8,
        'kbit': _ * (2 ** 30) * 8 / 1000,
        'mbit': _ * (2 ** 30) * 8 / 1000000,
        'gbit': _ * (2 ** 30) * 8 / 1000000000,
        'tbit': _ * (2 ** 30) * 8 / 1000000000000,

        'kib': _ * (2 ** 20),
        'mib': _ * (2 ** 10),
        'gib': _,
        'tib': _ / (2 ** 10),
    },
    'tib': {
        'b': _ * (2 ** 40),
        'kb': _ * (2 ** 40) / 1000,
        'mb': _ * (2 ** 40) / 1000000,
        'gb': _ * (2 ** 40) / 1000000000,
        'tb': _ * (2 ** 40) / 1000000000000,

        'bit':  _ * (2 ** 40) * 8,
        'kbit': _ * (2 ** 40) * 8 / 1000,
        'mbit': _ * (2 ** 40) * 8 / 1000000,
        'gbit': _ * (2 ** 40) * 8 / 1000000000,
        'tbit': _ * (2 ** 40) * 8 / 1000000000000,

        'kib': _ * (2 ** 30),
        'mib': _ * (2 ** 20),
        'gib': _ * (2 ** 10),
        'tib': _,
    },
}
