from decimal import Decimal as d
from plz.functional import _


UNITS = [
    ('mm', 'millimeter', 'millimeters'),
    ('cm', 'centimeter', 'centimeters'),
    ('m', 'meter', 'meters'),
    ('km', 'kilometer', 'kilometers'),
    ('ft', 'foot', 'feet',),
    ('in', 'inch', 'inches',),
    ('mile', 'miles',),
    ('yd', 'yard', 'yards',)
]


CONV = {
    'mm': {
        'mm': _,
        'cm': _ / 10,
        'm': _ / 1000,
        'km': _ / 1000000,
        'ft': _ / d('0.3048') / 1000,
        'in': _ / d('2.54') / 10,
        'mile': _ / d('1609.344') / 1000,
        'yd': _ / d('0.9144') / 1000,
    },
    'cm': {
        'mm': _ * 10,
        'cm': _,
        'm': _ / 100,
        'km': _ / 100000,
        'ft': _ / d('0.3048') / 100,
        'in': _ / d('2.54'),
        'mile': _ / d('1609.344') / 100,
        'yd': _ / d('0.9144') / 100,
        },
    'm': {
        'mm': _ * 1000,
        'cm': _ * 100,
        'm': _,
        'km': _ / 1000,
        'ft': _ / d('0.3048'),
        'in': _ / d('2.54') * 100,
        'mile': _ / d('1609.344'),
        'yd': _ / d('0.9144'),
    },
    'km': {
        'mm': _ * 1000000,
        'cm': _ * 100000,
        'm': _ * 1000,
        'km': _,
        'ft': _ / d('0.3048') * 1000,
        'in': _ / d('2.54') * 100000,
        'mile': _ / d('1609.344') * 1000,
        'yd': _ / d('0.9144') * 1000,
    },
    'ft': {
        'mm': _ * d('0.3048') * 1000,
        'cm': _ * d('0.3048') * 100,
        'm': _ * d('0.3048'),
        'km': _ * d('0.3048') / 1000,
        'ft': _,
        'in': _ * 12,
        'mile': _ / 1760 / 3,
        'yd': _ / 3,
    },
    'in': {
        'mm': _ * d('2.54') * 10,
        'cm': _ * d('2.54'),
        'm': _ * d('2.54') / 100,
        'km': _ * d('2.54') / 100000,
        'ft': _ / 12,
        'in': _,
        'mile': _ / 1760 / 36,
        'yd': _ / 36,
        },
    'mile': {
        'mm': _ * d('1609.344') * 1000,
        'cm': _ * d('1609.344') * 100,
        'm': _ * d('1609.344'),
        'km': _ * d('1609.344') / 1000,
        'ft': _ * 1760 * 3,
        'in': _ * 1760 * 36,
        'mile': _,
        'yd': _ * 1760,
    },
    'yd': {
        'mm': _ * d('0.9144') * 1000,
        'cm': _ * d('0.9144') * 100,
        'm': _ * d('0.9144'),
        'km': _ * d('0.9144') / 1000,
        'ft': _ * 3,
        'in': _ * 36,
        'mile': _ / 1760,
        'yd': _,
    },
}
