from decimal import Decimal as d
from plz.functional import _


UNITS = [
    ('mg', 'milligram',),
    ('g', 'gram', 'gr',),
    ('kg', 'kilogram', 'kilo'),
    ('t', 'tonne', 'tonnes'),
    ('lb', 'pound', 'pounds', 'lbs', 'lbm'),
    ('oz', 'ounce', 'ounces',),
]


CONV = {
    'mg': {
        'mg': _,
        'g': _ / 1000,
        'kg': _ / 1000000,
        't': _ / 1000000000,
        'lb': _ / d('453.59237') / 1000,
        'oz': _ / d('28.349523125') / 1000,
    },
    'g': {
        'mg': _ * 1000,
        'g': _,
        'kg': _ / 1000,
        't': _ / d('1e+6'),
        'lb': _ / d('453.59237'),
        'oz': _ / d('28.349523125'),
    },
    'kg': {
        'mg': _ * 1000000,
        'g': _ * 1000,
        'kg': _,
        't': _ / 1000,
        'lb': _ / d('453.59237') * 1000,
        'oz': _ / d('28.349523125') * 1000,
    },
    't': {
        'mg': _ * d('1e+9'),
        'g': _ * d('1e+6'),
        'kg': _ * 1000,
        't': _,
        'lb': _ / d('453.59237') * d('1e+6'),
        'oz': _ / d('28.349523125') * d('1e+6'),
    },
    'lb': {
        'mg': _ * d('453.59237') * 1000,
        'g': _ * d('453.59237'),
        'kg': _ * d('453.59237') / 1000,
        't': _ * d('453.59237') * d('1e+6'),
        'lb': _,
        'oz': _ * d(16),
    },
    'oz': {
        'mg': _ * d('28.349523125') * 1000,
        'g': _ * d('28.349523125'),
        'kg': _ * d('28.349523125') / 1000,
        't': _ * d('28.349523125') / d('1e+6'),
        'lb': _ / 16,
        'oz': _,
    },
}
